@@ -150,7 +150,7 @@ class Server(object):
             found = False
             while not found:
                 where = logfile.tell()
-                line - logfile.readline()
+                line = logfile.readline()
                 if not line:
                     time.sleep(0.1)
                     logfile.seek(where)
